# py-finstmt

## Overview

Work with financial statement data in Python. Can calculate free cash flows and help project
financial statements.


## Links

See the
[documentation here.](
https://nickderobertis.github.io/py-finstmt/
)

## Author

Created by Nick DeRobertis. MIT License.